/// <reference types="node" />
import execa from 'execa';
export { execa };
export declare function exec(command: string, options?: execa.Options): execa.ExecaChildProcess;
export declare function exec(commands: string[], options?: execa.Options): Promise<execa.ExecaSyncReturnValue<string>[]>;
export declare const spawn: {
    (file: string, arguments?: readonly string[] | undefined, options?: execa.Options<string> | undefined): execa.ExecaChildProcess<string>;
    (file: string, arguments?: readonly string[] | undefined, options?: execa.Options<null> | undefined): execa.ExecaChildProcess<Buffer>;
    (file: string, options?: execa.Options<string> | undefined): execa.ExecaChildProcess<string>;
    (file: string, options?: execa.Options<null> | undefined): execa.ExecaChildProcess<Buffer>;
    sync(file: string, arguments?: readonly string[] | undefined, options?: execa.SyncOptions<string> | undefined): execa.ExecaSyncReturnValue<string>;
    sync(file: string, arguments?: readonly string[] | undefined, options?: execa.SyncOptions<null> | undefined): execa.ExecaSyncReturnValue<Buffer>;
    sync(file: string, options?: execa.SyncOptions<string> | undefined): execa.ExecaSyncReturnValue<string>;
    sync(file: string, options?: execa.SyncOptions<null> | undefined): execa.ExecaSyncReturnValue<Buffer>;
    command(command: string, options?: execa.Options<string> | undefined): execa.ExecaChildProcess<string>;
    command(command: string, options?: execa.Options<null> | undefined): execa.ExecaChildProcess<Buffer>;
    commandSync(command: string, options?: execa.SyncOptions<string> | undefined): execa.ExecaSyncReturnValue<string>;
    commandSync(command: string, options?: execa.SyncOptions<null> | undefined): execa.ExecaSyncReturnValue<Buffer>;
    node(scriptPath: string, arguments?: readonly string[] | undefined, options?: execa.NodeOptions<string> | undefined): execa.ExecaChildProcess<string>;
    node(scriptPath: string, arguments?: readonly string[] | undefined, options?: execa.Options<null> | undefined): execa.ExecaChildProcess<Buffer>;
    node(scriptPath: string, options?: execa.Options<string> | undefined): execa.ExecaChildProcess<string>;
    node(scriptPath: string, options?: execa.Options<null> | undefined): execa.ExecaChildProcess<Buffer>;
};
export declare class ShellContext {
    private _cwdStack;
    private _env;
    logCommand: boolean;
    sleep: (ms: number) => Promise<void>;
    /**
     * get current word directory
     */
    get cwd(): string;
    protected _logger: import("./logger").Logger;
    /**
     * change work directory
     * @param dir
     */
    cd(dir: string): this;
    /**
     * like pushd in shell
     * @param dir
     */
    pushd(dir: string): this;
    /**
     * like popd in shell
     */
    popd(): this;
    /**
     * execute command(s)
     * @param command
     * @param options
     */
    exec(command: string, options?: execa.Options): execa.ExecaChildProcess;
    exec(commands: string[], options?: execa.Options): Promise<execa.ExecaSyncReturnValue[]>;
    /**
     * spawn file
     * @param file
     * @param args
     * @param options
     */
    spawn(file: string, args?: string[], options?: execa.Options): execa.ExecaChildProcess;
    /**
     * set/get/delete env
     * set: ctx.env('key', 'val')
     * get: ctx.env('key')
     * delete: ctx.env('key', void 0)
     * @param key
     */
    env(key: string): string | undefined;
    env(key: string, val: string | undefined): this;
    /**
     * restart processes when file changes
     */
    monitor(dir: string, run: (ctx: ShellContext) => execa.ExecaChildProcess | Promise<execa.ExecaChildProcess>, { throttle }: {
        throttle?: number;
    }): void;
    /**
     * reset env to default
     */
    resetEnv(): this;
    private _logCmd;
}
export declare function shell(callback: (ctx: ShellContext) => Promise<any>): Promise<any>;
